@@ -1,4 +1,4 @@
-/* $Id: generate_defs_libglade.cc,v 1.2 2002/04/19 09:11:12 murrayc Exp $ */
+/* $Id: generate_defs_libglade.cc,v 1.3 2003/11/03 09:37:48 murrayc Exp $ */
 
 /* generate_defs_libglade.h
  *
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "gtkmm_generate_extra_defs/generate_extra_defs.h"
+#include "glibmm_generate_extra_defs/generate_extra_defs.h"
 #include <glade/glade.h>
 #include <gtk/gtk.h>
 
